==> haskell-foldl-1.4.5-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.4.5
id: foldl-1.4.5-Grd403l3ON87kHpULn968d
key: foldl-1.4.5-Grd403l3ON87kHpULn968d
license: BSD-3-Clause
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
abi: 9d9813223c5adb839309e6958b745995
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl
hidden-modules: Control.Foldl.Optics Control.Foldl.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/foldl-1.4.5
hs-libraries: HSfoldl-1.4.5-Grd403l3ON87kHpULn968d
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    comonad-5.0.5-CthxCPGmo5h60L0drN1HHd containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    profunctors-5.4-FuMvsq9p4l3CSxuI1XIcXh
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-builder-0.3.7.2-2N4jYCJsZ1xE8vM12T7uKn
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.5-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.4.5
id: foldl-1.4.5-LfxLFKcBt2X26jKeIVEEHW
key: foldl-1.4.5-LfxLFKcBt2X26jKeIVEEHW
license: BSD-3-Clause
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
abi: 9d32748ea5939cc81fc160f01cc80d10
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl
hidden-modules: Control.Foldl.Optics Control.Foldl.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/foldl-1.4.5
hs-libraries: HSfoldl-1.4.5-LfxLFKcBt2X26jKeIVEEHW
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    comonad-5.0.5-CthxCPGmo5h60L0drN1HHd containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mwc-random-0.14.0.0-3OEYgJnrFeWFi8tMJuzC34
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    profunctors-5.5-C3RSa0newLDGrqKqFpjE7c
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-builder-0.3.7.2-2N4jYCJsZ1xE8vM12T7uKn
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
